==> haskell-http-types-0.9.1-10-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
key: http-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: ebccb60d3ac5df54aab204823e5973ab
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.1/site-local/http-types-0.9.1
data-dir: /usr/share/x86_64-linux-ghc-8.0.1/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-3nvMCSru4dgGbycKqlKoUe
depends:
    array-0.5.1.1 base-4.9.0.0
    blaze-builder-0.4.0.2-J9puUMdRFvA3rt0D0pNg3S bytestring-0.10.8.1
    case-insensitive-1.2.0.10-1SnYCB9JRtzhTT2S8jwYb
    text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-http-types-0.9.1-11-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-http-types.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: http-types
version: 0.9.1
id: http-types-0.9.1-F0xB6ibhSLtF4hUyLFQyQA
key: http-types-0.9.1-F0xB6ibhSLtF4hUyLFQyQA
license: BSD3
copyright: (C) 2011 Aristid Breitkreuz
maintainer: aristidb@googlemail.com
homepage: https://github.com/aristidb/http-types
synopsis: Generic HTTP types for Haskell (for both client and server code).
description:
    Generic HTTP types for Haskell (for both client and server code).
category: Network, Web
author: Aristid Breitkreuz, Michael Snoyman
exposed: True
exposed-modules:
    Network.HTTP.Types Network.HTTP.Types.Header
    Network.HTTP.Types.Method Network.HTTP.Types.QueryLike
    Network.HTTP.Types.Status Network.HTTP.Types.URI
    Network.HTTP.Types.Version
abi: 363d13884898e367408f11261f090344
trusted: False
import-dirs: /usr/lib/ghc-8.0.2/site-local/http-types-0.9.1
library-dirs: /usr/lib/ghc-8.0.2/site-local/http-types-0.9.1
dynamic-library-dirs: /usr/lib/x86_64-linux-ghc-8.0.2
data-dir: /usr/share/x86_64-linux-ghc-8.0.2/http-types-0.9.1
hs-libraries: HShttp-types-0.9.1-F0xB6ibhSLtF4hUyLFQyQA
depends:
    array-0.5.1.1 base-4.9.1.0
    blaze-builder-0.4.0.2-EbETJDFSQ4b6W7B283dutO bytestring-0.10.8.1
    case-insensitive-1.2.0.10-FRqGPugKcXCDhucdrD5I1k
    text-1.2.2.2-3ENqlljngKa6xj1Go2fVWq
haddock-interfaces: /usr/share/doc/haskell-http-types/html/http-types.haddock
haddock-html: /usr/share/doc/haskell-http-types/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
